@@ -1,6 +1,6 @@
 """programmatic drawio export"""
 
-# Copyright 2021 ipydrawio contributors
+# Copyright 2022 ipydrawio contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import json
 from pathlib import Path
 
 from ._version import __js__, __version__
@@ -24,14 +25,15 @@ from .serverextension import load_jupyter_server_extension
 def _jupyter_labextension_paths():
     """static paths to link for interactive installation"""
     here = Path(__file__).parent
-
-    return [
-        dict(
-            src=f"{pkg.parent.relative_to(here).as_posix()}",
-            dest=f"{pkg.parent.parent.name}/{pkg.parent.name}",
-        )
-        for pkg in (here / "labextensions").glob("*/*/package.json")
-    ]
+    exts = []
+    for pkg in here.glob("ext/*/package.json"):
+        exts += [
+            dict(
+                src=str(pkg.parent.relative_to(here).as_posix()),
+                dest=json.loads(pkg.read_text(encoding="utf-8"))["name"],
+            )
+        ]
+    return exts
 
 
 def _jupyter_server_extension_paths():
