@@ -1,6 +1,6 @@
 """ source of truth for ipydrawio-export version"""
 
-# Copyright 2021 ipydrawio contributors
+# Copyright 2022 ipydrawio contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,11 +20,7 @@ from pathlib import Path
 
 HERE = Path(__file__).parent
 
-__js__ = json.loads(
-    (HERE / "labextensions/@deathbeds/ipydrawio-pdf/package.json").read_text(
-        encoding="utf-8"
-    )
-)
+__js__ = json.loads((HERE / "ext/ipdpdf/package.json").read_text(encoding="utf-8"))
 
 __version__ = __js__["version"]
 
