@@ -1,6 +1,6 @@
 """CLI for ipydrawio-export"""
 
-# Copyright 2021 ipydrawio contributors
+# Copyright 2022 ipydrawio contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -37,7 +37,7 @@ class BaseApp(Application):
 
 
 class ManagedApp(BaseApp):
-    drawio_manager = T.Instance(IPyDrawioExportManager)
+    drawio_manager: IPyDrawioExportManager = T.Instance(IPyDrawioExportManager)
     io_loop = T.Instance(ioloop.IOLoop)
 
     @T.default("io_loop")
